@@ -17,11 +17,14 @@
 #include "analog.h"
 #include "avr_compat.h"
 #include "hardware_settings.h"
+#include "i2c_avr.h"
 #include <stdlib.h> // atoi
 #include <string.h> 
 #include <avr/eeprom.h> 
 
 static int set_val[2];
+static int measured_val[2];
+static char i2c_buf[MAX_BUF_LEN+1];
 // the set values but converted to ADC steps
 static int set_val_adcUnits[2]; 
 
@@ -173,10 +176,50 @@ static signed char check_buttons(void){
 	return(0);
 }
 
+void check_i2c_interface(void){
+	if (i2c_get_received_data(i2c_buf)){
+		if (i2c_buf[0]=='i'){
+			if (i2c_buf[1]=='=' && i2c_buf[2]!='\0'){
+				set_val[0]=atoi(&i2c_buf[2]);
+				if(set_val[0]>I_MAX){
+					set_val[0]=I_MAX;
+				}
+				if(set_val[0]<0){
+					set_val[0]=0;
+				}
+				i2c_send_data("ok");
+			}else{
+				int_to_ascii(measured_val[0],i2c_buf,2,0);
+				strcat(i2c_buf,"A");
+				i2c_send_data(i2c_buf);
+			}
+		}else if (i2c_buf[0]=='s'){
+			store_permanent();
+			i2c_send_data("ok");
+		}else if (i2c_buf[0]=='u'){
+			if (i2c_buf[1]=='=' && i2c_buf[2]!='\0'){
+				set_val[1]=atoi(&i2c_buf[2]);
+				if(set_val[1]>U_MAX){
+					set_val[1]=U_MAX;
+				}
+				if(set_val[1]<0){
+					set_val[1]=0;
+				}
+				i2c_send_data("ok");
+			}else{
+				int_to_ascii(measured_val[1],i2c_buf,1,0);
+				strcat(i2c_buf,"V");
+				i2c_send_data(i2c_buf);
+			}
+		}else{
+			i2c_send_data("err");
+		}
+	}
+}
+
 void main(void)
 {
 	char out_buf[20+1];
-	int measured_val[2];
 	measured_val[0]=0;
 	measured_val[1]=0;
 	init_dac();
@@ -188,7 +231,10 @@ void main(void)
 		set_val[1]=eeprom_read_word((uint16_t *)0x04);
 		set_val[0]=eeprom_read_word((uint16_t *)0x02);
 	}
+	// I2C also called TWI
+	i2c_init(3,1,0);
 	sei();
+	i2c_send_data("on");
 	init_analog();
 	while (1) {
 
@@ -231,16 +277,20 @@ void main(void)
 		//dbg
 		//int_to_ascii(is_dacval(),out_buf,0,0);
 		//lcd_puts(out_buf);
+		check_i2c_interface();
 
 		// the buttons must be responsive but they must not 
 		// scroll too fast if pressed permanently
 		if (!check_buttons()){
 			// no buttons pressed
 			delay_ms(100);
+			check_i2c_interface();
 			check_buttons();
 			delay_ms(100);
 		}else{
-			delay_ms(200);
+			delay_ms(100);
+			check_i2c_interface();
+			delay_ms(100);
 		}
 	}
 }
